function D = makealbedo(type,r,s)
%MAKEALBEDO create an albedo matrix.
%   D = makealbedo(type,r,s) create the albedo matrix of size s x r.
%   type can be 1 (all ones), 2 (a gray centered circle), or 3 (a colour clown).
%
%   See also datasynth, testsynth, and testshell.

%   A. Concas, E. Crabu, R. Dessì, C. Fenu, G. Rodriguez & M. Vanzi
%   Email: concas.anna@gmail.com, elisa.crabu@unica.it, richidessi@gmail.com,
%   kate.fenu@unica.it, rodriguez@unica.it, vanzi@diee.unica.it
%
%   Last revised August, 2024

switch type

case 1
	D = ones(s,r); 

case 2
	D = ones(s,r); 
%	xc = round(r/2);
%	yc = round(s/2);
	x = linspace(-1,1,r);
	y = linspace(-1,1,s);
	[X,Y] = meshgrid(x,y);
	r = 1/2;
	D((X.^2+Y.^2)<r^2) = 0.5;

case 3
	load mandrill
	IM = ind2rgb(X,map);
	D = double(imresize(IM,[s,r]));

otherwise
	error('Unknown albedo type.')
end

